@@ -1,5 +1,5 @@
 package List::Objects::WithUtils::Role::Array::Typed;
-$List::Objects::WithUtils::Role::Array::Typed::VERSION = '2.011002';
+$List::Objects::WithUtils::Role::Array::Typed::VERSION = '2.012001';
 use strictures 1;
 
 use Carp ();
@@ -7,10 +7,16 @@ use Scalar::Util ();
 use Type::Tie ();
 
 use Role::Tiny;
-requires 'type', 'new';
+requires 'type', 'untyped', 'new';
 
 around type => sub { tied(@{$_[1]})->type };
 
+around untyped => sub {
+  my (undef, $self) = @_;
+  require List::Objects::WithUtils::Array;
+  List::Objects::WithUtils::Array->new(@$self)
+};
+
 around new => sub {
   # yes, this splice is correct:
   my (undef, $class, $type) = splice @_, 0, 2;
@@ -84,6 +90,14 @@ Also see L<Types::Standard>, L<List::Objects::Types>
 
 Returns the L<Type::Tiny> type the object was created with.
 
+=head2 untyped
+
+Returns a (shallow) clone that is a plain L<List::Objects::WithUtils::Array>.
+
+Since most methods that return a new list will (attempt to) return a list
+object of the same type as their parent, this can be useful to avoid type
+check failures in a method chain that creates intermediate lists.
+
 =head1 AUTHOR
 
 Jon Portnoy <avenj@cobaltirc.org> with significant contributions from Toby
